<?php
/**
 * WPS_maganizer functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * WPS_maganizer
 */

if ( ! function_exists( 'maganizer_base_setup' ) ) :

	function maganizer_base_setup() {

		load_theme_textdomain( 'maganizer', get_template_directory() . '/languages' );

		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'title-tag' );

        add_theme_support( 'post-thumbnails' );
        add_image_size( 'maganizer-extra-full-page-thumb', 1200, 1200, true );
        add_image_size( 'maganizer-main-post-thumb', 1000, 900, true );
        add_image_size( 'maganizer-large-post-thumb', 800, 600, true );
        add_image_size( 'maganizer-middle-post-thumb', 600, 400, true );
        add_image_size( 'maganizer-medium-post-thumb', 440, 340, true );
        add_image_size( 'maganizer-small-post-thumb', 140, 100, true );

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );


		// Adding support for core block visual styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add support for responsive embeds.
		add_theme_support( 'responsive-embeds' );
	}
endif;
add_action( 'after_setup_theme', 'maganizer_base_setup' );

/**
 * Register Google Fonts
 */
function maganizer_fonts_url() {
    $fonts_url = '';
    $fonts     = array();
    $subsets   = 'latin,latin-ext';

    /*
     * Translators: If there are characters in your language that are not supported
     * by Oswald, translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Roboto font: on or off', 'maganizer' ) ) {
        $fonts[] = 'Poppins:400,500,700';
    }

    /*
     * Translators: If there are characters in your language that are not supported
     * by Montserrat, translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Raleway font: on or off', 'maganizer' ) ) {
        $fonts[] = 'Raleway:500,600';
    }


    if ( $fonts ) {
        $fonts_url = add_query_arg( array(
            'family' => urlencode( implode( '|', $fonts ) ),
            'subset' => urlencode( $subsets ),
        ), 'https://fonts.googleapis.com/css' );
    }

    return esc_url_raw( $fonts_url );
}

/**
 * Enqueue scripts and styles.
 */
function maganizer_scripts() {

    //Css
    wp_enqueue_style( 'maganizer-style', get_stylesheet_uri() );
    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap-grid.min.css' );
    wp_enqueue_style('owl-carousel', get_template_directory_uri() . '/css/owl.carousel.min.css');
    wp_enqueue_style( 'font-awesome-four', get_template_directory_uri() . '/css/all.min.css' );
    wp_enqueue_style( 'maganizer-blocks-main-style', get_template_directory_uri() . '/css/wps_style.css' );

    //RTL and Uncompressed Style Font
    if ( function_exists('WPS_framework_init') && wps_get_option('rtl_support' ) == '1' ) {
        wp_enqueue_style('maganizer-blocks-rtl-style', get_template_directory_uri() . '/css/rtl.css');
    }
    wp_enqueue_style( 'maganizer-fonts', maganizer_fonts_url() );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

    wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/js/owl.carousel.min.js', array( 'jquery' ), '20151215', true );
    wp_enqueue_script( 'jquery-tickerme', get_template_directory_uri() . '/js/instastory.js', array( 'jquery' ), '20151215', true );
    wp_enqueue_script( 'maganizer-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array( 'jquery' ), '20151215', true );
    wp_enqueue_script( 'bootstarp', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), '20151215', true );
    wp_enqueue_script( 'scrollbar', get_template_directory_uri() . '/js/jquery.scrollbar.js', array( 'jquery' ), '20151215', true );
    wp_enqueue_script('maganizer-custom-script', get_template_directory_uri() . '/js/wps-changes.js', array('jquery'), '20151215', true);
    if ( function_exists('WPS_framework_init')){
    wp_enqueue_script('maganizer-fixed-menu', get_template_directory_uri() . '/js/wps-fixed-menu.js', array('jquery'), '20151215', true);
    }

}
add_action( 'wp_enqueue_scripts', 'maganizer_scripts' );

//Admin area Gburg
function my_admin_style() {
    wp_enqueue_style( 'admin-style', get_stylesheet_directory_uri() . '/css/wps_admin.css' );
}
add_action( 'admin_enqueue_scripts', 'my_admin_style');

//Theme Time displays your post date in time ago format */
function maganizer_posttime() {
    return human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ).' '.__( 'ago', 'maganizer' );
}


/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**if ( ! isset( $content_width ) ) $content_width = 900;
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Import Demo Data
 */
require get_template_directory() . '/importer/import_data.php';


function maganizer_max_charlength($charlength) {
    $excerpt = get_the_excerpt();
    $charlength++;
    if ( mb_strlen( $excerpt ) > $charlength ) {
        $subex = mb_substr( $excerpt, 0, $charlength - 5 );
        $exwords = explode( ' ', $subex );
        $excut = - ( mb_strlen( $exwords[ count( $exwords ) - 1 ] ) );
        if ( $excut < 0 ) {
            echo mb_substr( $subex, 0, $excut );
        } else {
            echo esc_attr($subex);
        }
        echo '...';
    } else {
        echo esc_attr($excerpt);
    }
}

//Default sidebar
function maganizer_sidebars() {
    register_sidebar(
        array (
            'name' => esc_html__( 'Right Sidebar', 'maganizer' ),
            'id' => 'custom-side-bar',
            'description' => esc_html__( 'Default Sidebar', 'maganizer' ),
            'before_widget' => '<div class="widget-content">',
            'after_widget' => "</div>",
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        )
    );

    register_sidebar(
        array (
            'name' => esc_html__( 'Shop Page Sidebar', 'maganizer' ),
            'id' => 'woo-shop-sidebar',
            'description' => esc_html__( 'Woocommerce Shop Sidebar', 'maganizer' ),
            'before_widget' => '<div class="widget-content">',
            'after_widget' => "</div>",
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        )
    );
}
add_action( 'widgets_init', 'maganizer_sidebars' );

//Post Format Added
add_theme_support( 'post-formats', array( 'video', 'gallery', 'quote', 'audio' ) );

//Post Views
function getPostViews($postID){
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return "0";
    }
    return $count;
}

function setPostViews($postID) {
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}

// Author Bio Facebook, Twitter Link Enable And Add It to Bio page
function maganizer_author_contact( $contactmethods ) {
    unset( $contactmethods[ 'aim' ] );
    unset( $contactmethods[ 'yim' ] );
    unset( $contactmethods[ 'jabber' ] );
    $contactmethods[ 'twitter' ] = 'Twitter URL here';
    $contactmethods[ 'facebook' ] = 'Facebook URL here';
    $contactmethods[ 'vk' ] = 'VK URL Here';
    $contactmethods[ 'pintrest' ] = 'Add Printerest URL Here';
    $contactmethods[ 'linkedin' ] = 'Add Linked In URL Here';
    $contactmethods[ 'youtube' ] = 'Add Youtube URL Here';
    $contactmethods[ 'dribbble' ] = 'Add dribbble URL Here';
    return $contactmethods;
}
add_filter( 'user_contactmethods', 'maganizer_author_contact' );


//Menu Register
if (function_exists('register_nav_menus'))
{
    register_nav_menus(array(
        'main_nav' =>  esc_html__('Main Navigation Menu', 'maganizer')
    ));
}

if (function_exists('register_nav_menus'))
{
    register_nav_menus(array(
        'slide_nav' =>  esc_html__('Slide Menu', 'maganizer')
    ));
}

if (function_exists('WPS_framework_init')) {
//Sub Menu Active when Plugin Installed
    if (function_exists('register_nav_menus')) {
        register_nav_menus(array(
            'top_nav' => esc_html__('Top Menu (No Submenu)', 'maganizer')
        ));
    }

}

//Add Woocommerce Support
function maganizer_woocommerce_support() {
    add_theme_support( 'woocommerce' );
}

add_action( 'after_setup_theme', 'maganizer_woocommerce_support' );

//Top cart
add_filter('woocommerce_add_to_cart_fragments', 'maganizer_add_to_cart_fragment');

function maganizer_add_to_cart_fragment( $fragments ) {
    global $woocommerce;

    ob_start();

    ?>
        <a class="cart-contents" href="<?php echo esc_url($woocommerce->cart->get_cart_url()); ?>" ><?php echo sprintf(_n('%d', '%d', $woocommerce->cart->cart_contents_count, 'maganizer'), $woocommerce->cart->cart_contents_count);?></a>
    <?php

    $fragments['a.cart-contents'] = ob_get_clean();

    return $fragments;

}

//TGM Plugin
require get_template_directory() . '/importer/plugin/wpsmart_installer.php';

//Ajax Load more
require get_template_directory() . '/template-parts/ajax-more.php';
require get_template_directory() . '/template-parts/ajax-more-style.php';
require get_template_directory() . '/template-parts/ajax-more-simple.php';


if (function_exists('WPS_framework_init')) {

    add_filter('loop_shop_per_page', 'maganizer_shop_per_page', 20);

    function maganizer_shop_per_page($cols)
    {
        // $cols contains the current number of products per page based on the value stored on Options -> Reading
        // Return the number of products you wanna show per page.
        $cols = 9;
        return $cols;
    }
}

if ( strpos( ini_get( 'disable_functions' ), 'set_time_limit' ) === false ) {
    set_time_limit( apply_filters( 'pt-ocdi/set_time_limit_for_demo_data_import', 300 ) );
}

$disabled = explode(',', ini_get('disable_functions'));
if( !ini_get('safe_mode') && !in_array('set_time_limit', $disabled) ) {
    set_time_limit( apply_filters( 'pt-ocdi/set_time_limit_for_demo_data_import', 300 ) );
}