<?php
/**
 * Theme dashboard system information section
 *
 * @package maganizer_wps_dashboard
 */

?>
<?php

if( ! class_exists( 'maganizer_wps_dashboard_System' ) ) {
	class maganizer_wps_dashboard_System {
		public function __construct() {

			if( ! is_admin() ){
				return;
			}

			$this->main();
		}

		public function main(){

			add_action('admin_menu', array($this, 'add_menu_link'), 15);

		}

		function add_menu_link(){

			$page_title = esc_html__('System Information', 'maganizer');
			add_theme_page( $page_title, $page_title, 'manage_options', 'maganizer_wps_dashboard_system_information', array( $this, 'dashboard_system' ), null, 3 );
		}

		public function let_to_num( $size ) {
		  $l   = substr( $size, -1 );
		  $ret = substr( $size, 0, -1 );
		  switch ( strtoupper( $l ) ) {
		    case 'P':
		      $ret *= 1024;
		    case 'T':
		      $ret *= 1024;
		    case 'G':
		      $ret *= 1024;
		    case 'M':
		      $ret *= 1024;
		    case 'K':
		      $ret *= 1024;
		  }
		  return $ret;
		}

		public function dashboard_system(){

			function get_plugin_version_number($plugin_name) {
			    // If get_plugins() isn't available, require it
			    if ( ! function_exists( 'get_plugins' ) )
			        require_once( ABSPATH . 'wp-admin/includes/plugin.php' );

			        // Create the plugins folder and file variables
			    $plugin_folder = get_plugins( '/' . $plugin_name );
			    $plugin_file = $plugin_name.'.php';

			    // If the plugin version number is set, return it
			    if ( isset( $plugin_folder[$plugin_file]['Version'] ) ) {
			        return $plugin_folder[$plugin_file]['Version'];

			    } else {
			    // Otherwise return null
			        return esc_html__('Plugin not installed', 'maganizer');
			    }
			}

			?>
			<div class="wrap about-wrap theme-dashboard-wrapper system-wrapper">

                <?php include get_template_directory() . '/importer/inc/header.php'; ?>
                <h2 class="nav-tab-wrapper">
                    <a href="<?php echo esc_url(admin_url( 'themes.php?page=maganizer_wps_dashboard' )); ?>" class="nav-tab"><?php esc_html_e( 'Getting started', 'maganizer' ); ?></a>
                    <?php if (function_exists('WPS_framework_init')) { ?>
                        <a href="<?php echo esc_url(admin_url( 'admin.php?page=wps-framework' )); ?>" class="nav-tab"><?php esc_html_e( 'Theme options', 'maganizer' ); ?></a>
                    <?php } ?>
                    <a href="<?php echo esc_url(admin_url( 'themes.php?page=maganizer_wps_dashboard_system_information' )); ?>" class="nav-tab nav-tab-active"><?php esc_html_e( 'System information', 'maganizer' ); ?></a>
                    <a href="<?php echo esc_url( 'http://spraythemes.com/' ); ?>" class="nav-tab" target="_blank"><?php esc_html_e( 'WPSmart Support', 'maganizer' ); ?></a>
                </h2>
				<div class="theme-system-wrapper">
				<?php

			 	echo '<ul>';

			 	echo '<li><strong>PHP version:</strong> '.phpversion().'</li>';

			 	echo '<li><strong>WordPress version:</strong> '.get_bloginfo( 'version' ).'</li>';

			    echo '<li><strong>Theme version:</strong> '.wp_get_theme()->get( 'Version' ).'</li>';

			    echo '<li><strong>Theme Addons version:</strong> '.get_plugin_version_number('maganizer_wps_dashboard-theme-addons').'</li>';

			    echo '<li><strong>WooCommerce version:</strong> '.get_plugin_version_number('woocommerce').'</li>';

				$memory_limit = $this->let_to_num(ini_get('memory_limit'));

				if ( $memory_limit < 512000000 ) {
					$memory_limit_message_html = ' <span class="configuration-error">WARNING: <strong>512MB</strong> value required.</span>';
					$hosting_passed = false;
				} else {
					$memory_limit_message_html = '';
				}

				echo '<li><strong>Server Memory Limit:</strong> '.size_format(esc_html($memory_limit)).wp_kses_post($memory_limit_message_html).'</li>';

				$memory_limit = $this->let_to_num( WP_MEMORY_LIMIT );

				if ( $memory_limit < 512000000 ) {
					$memory_limit_message_html = ' <span class="configuration-info">INFO: <strong>512MB</strong> value recommended. <a href="https://wordpress.org/support/article/editing-wp-config-php/" target="_blank">How to set?</a></span>';
				} else {
					$memory_limit_message_html = '';
				}

				echo '<li><strong>WordPress Memory Limit:</strong> '.size_format(esc_html($memory_limit)).'.'.wp_kses_post($memory_limit_message_html).'</li>';

				$time_limit = ini_get('max_execution_time');

				if ( $time_limit < 60 && $time_limit != 0 ) {
					$time_limit_message_html = ' <span class="configuration-error">WARNING: <strong>60</strong> value required</span>';
					$hosting_passed = false;
				} else {
					$time_limit_message_html = '';
				}

				echo '<li><strong>Max Execution Time:</strong> '.esc_html($time_limit).' seconds '.wp_kses_post($time_limit_message_html).'</li>';

				$max_input_vars = ini_get('max_input_vars');

				if ( $max_input_vars < 1000 && $max_input_vars != 0 || $max_input_vars == '' ) {
					$max_input_vars_limit_message_html = ' <span class="configuration-info">INFO: <strong>1000</strong> value recommended.</span>';
				} else {
					$max_input_vars_limit_message_html = '';
				}

				if($max_input_vars == '') {
					$max_input_vars = 'Not set';
				}

				echo '<li><strong>Max Input Vars:</strong> '.esc_html($max_input_vars).' '.wp_kses_post($max_input_vars_limit_message_html).'</li>';

				$s_max_input_vars = ini_get( 'suhosin.post.max_vars' );

				if(!empty($s_max_input_vars)) {

					if ( $s_max_input_vars < 1000 && $s_max_input_vars != 0 ) {
						$max_input_vars_limit_message_html = ' <span class="configuration-info">INFO: <strong>1000</strong> value recommended.</span>';
					} else {
						$max_input_vars_limit_message_html = '';
					}

					echo '<li><strong>Suhosin Post Max Vars:</strong> '.esc_html($s_max_input_vars).'.'.wp_kses_post($max_input_vars_limit_message_html).'</li>';

			    }

				echo '</ul>';

				?>
                </div>
			</div>
			<?php
		}


	}
}

new maganizer_wps_dashboard_System;
